package org.bdware.server.nodecenter;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.bdware.sc.bean.ContractDesp;

import java.util.HashSet;
import java.util.Set;
import java.util.TimerTask;

public class CheckAgentAliveTimer extends TimerTask {
    private final String pubkey;
    static Logger LOGGER = LogManager.getLogger(CheckAgentAliveTimer.class);

    public CheckAgentAliveTimer(String pubKey) {
        this.pubkey = pubKey;
    }

    @Override
    public void run() {
        try {
            checkAlive();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void checkAlive() {
        Set<String> toRemove = new HashSet<>();
        CMNode info;
        info = NodeCenterActions.nodeInfos.get(pubkey);
        if (!info.checkAlive()) {
            synchronized (info) {
                if (null != info.contracts && !info.contracts.isEmpty()) {
                    for (ContractDesp cd : info.contracts) {
                        cd.setIsMaster(false);
                        //注意 选举不通过NC的机制触发。
                        LOGGER.info(
                                "checkAlive---- 设置节点 "
                                        + info.pubKey.substring(0, 5)
                                        + " 的合约 "
                                        + cd.contractID
                                        + " isMaster="
                                        + false);
                    }
                }
            }
        }
        NodeCenterActions.nodeInfos.remove(pubkey);
        try {
            info.connection.controller.ctx.close();
        } catch (Exception ignored) {
        }
    }
}
